@@ -42,7 +42,7 @@ from phonopy.interface import (read_crystal_structure,
                                get_default_physical_units)
 from phonopy.file_IO import (parse_FORCE_SETS, parse_BORN,
                              parse_FORCE_CONSTANTS, read_force_constants_hdf5)
-from phonopy.units import VaspToTHz
+
 
 def fracval(frac):
     if frac.find('/') == -1:
@@ -51,6 +51,7 @@ def fracval(frac):
         x = frac.split('/')
         return float(x[0]) / float(x[1])
 
+
 def get_cell(cell_filename, interface_mode, yaml_mode=False):
     cell, optional_structure_file_information = read_crystal_structure(
         filename=cell_filename,
@@ -63,6 +64,7 @@ def get_cell(cell_filename, interface_mode, yaml_mode=False):
 
     return cell
 
+
 def get_phonon(cell_filename,
                force_sets_filename,
                dim,
@@ -88,9 +90,9 @@ def get_phonon(cell_filename,
         if nac_params['factor'] is None:
             nac_params['factor'] = physical_units['nac_factor']
         phonon.set_nac_params(nac_params)
-    phonon.set_dynamical_matrix()
     return phonon
 
+
 def get_phonon_from_force_constants(cell_filename,
                                     force_constants_filename,
                                     dim,
@@ -117,12 +119,12 @@ def get_phonon_from_force_constants(cell_filename,
         nac_params = parse_BORN(phonon.get_primitive(),
                                 filename=born_filename,
                                 symprec=symprec)
-        if nac_params['factor'] == None:
+        if nac_params['factor'] is None:
             nac_params['factor'] = physical_units['nac_factor']
         phonon.set_nac_params(nac_params)
-    phonon.set_dynamical_matrix()
     return phonon
 
+
 def get_options():
     import argparse
     parser = argparse.ArgumentParser(
@@ -265,6 +267,7 @@ def get_options():
     args = parser.parse_args()
     return args
 
+
 def main(args):
     import warnings
     warnings.filterwarnings('error')
@@ -303,7 +306,6 @@ def main(args):
         print("--dim option has to be specified.")
         sys.exit(1)
 
-
     #
     # Phonopy gruneisen interface mode
     #
@@ -323,7 +325,6 @@ def main(args):
         interface_mode = 'vasp'
     physical_units = get_default_physical_units(interface_mode)
 
-
     if args.factor is not None:
         physical_units['factor'] = args.factor
 
@@ -332,7 +333,6 @@ def main(args):
     else:
         cell_filename = get_default_cell_filename(interface_mode)
 
-
     phonons = []
     for i in range(3):
         directory = args.dirnames[i]
@@ -376,9 +376,9 @@ def main(args):
                                 symprec=args.symprec)
             phonons.append(phonon)
 
-    gruneisen = PhonopyGruneisen(phonons[0], # equilibrium
-                                 phonons[1], # plus
-                                 phonons[2]) # minus
+    gruneisen = PhonopyGruneisen(phonons[0],  # equilibrium
+                                 phonons[1],  # plus
+                                 phonons[2])  # minus
 
     if args.plot_graph:
         if args.save_graph:
@@ -399,8 +399,9 @@ def main(args):
         gruneisen.set_band_structure(bands)
         gruneisen.write_yaml_band_structure()
         if args.plot_graph:
-            plt = gruneisen.plot_band_structure(epsilon=args.cutoff_wave_vector,
-                                                color_scheme=args.color_scheme)
+            plt = gruneisen.plot_band_structure(
+                epsilon=args.cutoff_wave_vector,
+                color_scheme=args.color_scheme)
             if args.title is not None:
                 plt.suptitle(args.title)
 
@@ -450,5 +451,6 @@ def main(args):
         else:
             plt.show()
 
+
 if __name__ == "__main__":
     main(get_options())
