@@ -36,7 +36,7 @@
 import sys
 import os
 import numpy as np
-from phonopy import Phonopy, PhonopyGruneisen, PhonopyQHA, __version__
+from phonopy import Phonopy, __version__
 import phonopy.file_IO as file_IO
 from phonopy.cui.settings import PhonopyConfParser
 from phonopy.cui.show_symmetry import check_symmetry
@@ -50,6 +50,7 @@ from phonopy.interface.phonopy_yaml import PhonopyYaml
 
 phonopy_version = __version__
 
+
 # AA is created at http://www.network-science.de/ascii/.
 def print_phononpy():
     print("""        _
@@ -59,6 +60,7 @@ def print_phononpy():
  | .__/|_| |_|\___/|_| |_|\___(_) .__/ \__, |
  |_|                            |_|    |___/""")
 
+
 def print_version(version):
     try:
         version_text = ('%s' % version).rjust(44)
@@ -81,6 +83,7 @@ def print_version(version):
         print(version_text)
         print('')
 
+
 def print_end():
     print("""                 _
    ___ _ __   __| |
@@ -89,6 +92,7 @@ def print_end():
   \___|_| |_|\__,_|
 """)
 
+
 def print_error():
     print("""  ___ _ __ _ __ ___  _ __
  / _ \ '__| '__/ _ \| '__|
@@ -96,16 +100,19 @@ def print_error():
  \___|_|  |_|  \___/|_|
 """)
 
+
 def print_attention(attention_text):
     print("*" * 67)
     print(attention_text)
     print("*" * 67)
     print('')
 
+
 def print_error_message(message):
     print('')
     print(message)
 
+
 def file_exists(filename, log_level):
     if os.path.exists(filename):
         return True
@@ -116,6 +123,7 @@ def file_exists(filename, log_level):
             print_error()
         sys.exit(1)
 
+
 def finalize_phonopy(log_level,
                      phonopy_conf,
                      phonon,
@@ -130,6 +138,7 @@ def finalize_phonopy(log_level,
         print_end()
     sys.exit(0)
 
+
 def print_cells(phonon, unitcell_filename):
     print("Crystal structure is read from \'%s\'." % unitcell_filename)
     supercell = phonon.get_supercell()
@@ -148,7 +157,7 @@ def print_cells(phonon, unitcell_filename):
         u2s_map = supercell.get_unitcell_to_supercell_map()
         print("-" * 30 + " primitive cell " + "-" * 30)
         print_cell(primitive, stars=p_indep_atoms)
-        print("-" * 32 + " unit cell " +  "-" * 33) # 32 + 11 + 33 = 76
+        print("-" * 32 + " unit cell " + "-" * 33)  # 32 + 11 + 33 = 76
         u2u_map = supercell.get_unitcell_to_unitcell_map()
         u_indep_atoms = [u2u_map[x] for x in s_indep_atoms]
         print_cell(unitcell, mapping=mapping[u2s_map], stars=u_indep_atoms)
@@ -156,6 +165,7 @@ def print_cells(phonon, unitcell_filename):
     print_cell(supercell, mapping=mapping, stars=s_indep_atoms)
     print("-" * 76)
 
+
 def print_settings(settings):
     run_mode = settings.get_run_mode()
     if run_mode == 'band':
@@ -222,7 +232,8 @@ def print_settings(settings):
             fmax = settings.get_max_frequency()
             text = None
             if (fmin is not None) and (fmax is not None):
-                text = "  - Phonon frequency from %5.3f to %5.3f" % (fmin, fmax)
+                text = "  - Phonon frequency from %5.3f to %5.3f" % (fmin,
+                                                                     fmax)
                 text += " are used to calculate\n"
                 text += "    thermal displacements."
             elif (fmin is None) and (fmax is not None):
@@ -235,8 +246,8 @@ def print_settings(settings):
                         text)
             if text:
                 print(text)
-    if (np.diag(np.diag(settings.get_supercell_matrix())) \
-            - settings.get_supercell_matrix()).any():
+    if (np.diag(np.diag(settings.get_supercell_matrix()))
+        - settings.get_supercell_matrix()).any():
         print("  Supercell matrix:")
         for v in settings.get_supercell_matrix():
             print("    %s" % v)
@@ -247,6 +258,7 @@ def print_settings(settings):
         for v in settings.get_primitive_matrix():
             print("    %s" % v)
 
+
 #################
 # Option parser #
 #################
@@ -437,7 +449,7 @@ if run_mode == 'displacements':
                      symprec=args.symprec,
                      is_symmetry=settings.get_is_symmetry(),
                      log_level=log_level)
-else: # Read FORCE_SETS, FORCE_CONSTANTS, or force_constants.hdf5
+else:  # Read FORCE_SETS, FORCE_CONSTANTS, or force_constants.hdf5
     # Overwrite frequency unit conversion factor
     if settings.get_frequency_conversion_factor() is not None:
         physical_units['factor'] = settings.get_frequency_conversion_factor()
@@ -484,9 +496,11 @@ else: # Read FORCE_SETS, FORCE_CONSTANTS, or force_constants.hdf5
             print("Force constants are read from %s." % fc_filename)
 
         if fc.shape[1] != num_satom:
-            error_text = ("Number of atoms in supercell is not consistent with "
-                          "the matrix shape of\nforce constants read from ")
-            if settings.get_is_hdf5() or settings.get_readfc_format() == 'hdf5':
+            error_text = ("Number of atoms in supercell is not consistent "
+                          "with the matrix shape of\nforce constants read "
+                          "from ")
+            if (settings.get_is_hdf5() or
+                settings.get_readfc_format() == 'hdf5'):
                 error_text += "force_constants.hdf5.\n"
             else:
                 error_text += "FORCE_CONSTANTS.\n"
@@ -547,7 +561,7 @@ if run_mode == 'displacements':
             displacement_distance = 0.02
         elif interface_mode == 'crystal':
             displacement_distance = 0.01
-        else: # default or vasp
+        else:  # default or vasp
             displacement_distance = 0.01
     else:
         displacement_distance = settings.get_displacement_distance()
@@ -558,10 +572,7 @@ if run_mode == 'displacements':
         is_diagonal=settings.get_is_diagonal_displacement(),
         is_trigonal=settings.get_is_trigonal_displacement())
     displacements = phonon.get_displacements()
-    directions = phonon.get_displacement_directions()
-    file_IO.write_disp_yaml(displacements,
-                            supercell,
-                            directions=directions)
+    file_IO.write_disp_yaml(displacements, supercell)
 
     # Write supercells with displacements
     cells_with_disps = phonon.get_supercells_with_displacements()
@@ -592,7 +603,7 @@ if run_mode == 'displacements':
                                             conv_numbers,
                                             settings.get_supercell_matrix(),
                                             template_file="TEMPLATE")
-    else: # default or vasp
+    else:  # default or vasp
         write_supercells_with_displacements(supercell, cells_with_disps)
 
     if log_level > 0:
@@ -621,7 +632,7 @@ if settings.get_is_nac():
             if log_level > 0:
                 print_error()
             sys.exit(1)
-        if nac_params['factor'] == None:
+        if nac_params['factor'] is None:
             nac_params['factor'] = physical_units['nac_factor']
         if settings.get_nac_method() is not None:
             nac_params['method'] = settings.get_nac_method()
@@ -653,7 +664,7 @@ elif os.path.exists("FORCE_SETS"):
     if settings.get_fc_spg_symmetry() or settings.get_is_full_fc():
         # Need to calculate full force constant tensors
         phonon.produce_force_constants()
-    else: # Only force constants between atoms in primitive cell and supercell
+    else:  # Only force constants between atoms in primitive cell and supercell
         phonon.produce_force_constants(calculate_full_force_constants=False)
 
 # Impose cutoff radius on force constants
@@ -784,7 +795,8 @@ elif run_mode == 'band' or run_mode == 'mesh' or run_mode == 'band_mesh':
                                              comment=comment)
 
         if args.is_graph_plot and run_mode != 'band_mesh':
-            plot = phonon.plot_band_structure(labels=settings.get_band_labels())
+            plot = phonon.plot_band_structure(
+                labels=settings.get_band_labels())
             if args.is_graph_save:
                 plot.savefig('band.pdf')
             else:
@@ -795,7 +807,7 @@ elif run_mode == 'band' or run_mode == 'mesh' or run_mode == 'band_mesh':
          mesh_shift,
          t_symmetry,
          q_symmetry,
-         is_gamma_center) =  settings.get_mesh()
+         is_gamma_center) = settings.get_mesh()
 
         if (settings.get_is_thermal_displacements() or
             settings.get_is_thermal_displacement_matrices()):
@@ -807,12 +819,13 @@ elif run_mode == 'band' or run_mode == 'mesh' or run_mode == 'band_mesh':
                     print_error()
                 sys.exit(1)
 
-            phonon.set_iter_mesh(mesh,
-                                 mesh_shift,
-                                 is_time_reversal=t_symmetry,
-                                 is_mesh_symmetry=q_symmetry,
-                                 is_eigenvectors=settings.get_is_eigenvectors(),
-                                 is_gamma_center=settings.get_is_gamma_center())
+            phonon.set_iter_mesh(
+                mesh,
+                mesh_shift,
+                is_time_reversal=t_symmetry,
+                is_mesh_symmetry=q_symmetry,
+                is_eigenvectors=settings.get_is_eigenvectors(),
+                is_gamma_center=settings.get_is_gamma_center())
         else:
             phonon.set_mesh(mesh,
                             mesh_shift,
@@ -935,22 +948,6 @@ elif run_mode == 'band' or run_mode == 'mesh' or run_mode == 'band_mesh':
             if t_cif is not None:
                 phonon.write_thermal_displacement_matrix_to_cif(0)
 
-        # Thermal distances
-        elif settings.get_is_thermal_distances():
-            if log_level > 0:
-                print("Calculating thermal distances...")
-            tprop_range = settings.get_thermal_property_range()
-            tstep = tprop_range['step']
-            tmax = tprop_range['max']
-            tmin = tprop_range['min']
-            phonon.set_thermal_distances(
-                settings.get_thermal_atom_pairs(),
-                tstep,
-                tmax,
-                tmin,
-                cutoff_frequency=settings.get_cutoff_frequency())
-            phonon.write_yaml_thermal_distances()
-
         # Partial DOS
         elif settings.get_pdos_indices() is not None:
             p_direction = settings.get_projection_direction()
